@@ -47,12 +47,14 @@
 #' @export aenet
 #'
 #' @examples
-#' dat = msaenet.sim.gaussian(n = 150, p = 500, rho = 0.6,
-#'                            coef = rep(1, 5), snr = 2, p.train = 0.7,
-#'                            seed = 1001)
+#' dat = msaenet.sim.gaussian(
+#'   n = 150, p = 500, rho = 0.6,
+#'   coef = rep(1, 5), snr = 2, p.train = 0.7,
+#'   seed = 1001)
 #'
-#' aenet.fit = aenet(dat$x.tr, dat$y.tr,
-#'                   alphas = seq(0.2, 0.8, 0.2), seed = 1002)
+#' aenet.fit = aenet(
+#'   dat$x.tr, dat$y.tr,
+#'   alphas = seq(0.2, 0.8, 0.2), seed = 1002)
 #'
 #' print(aenet.fit)
 #' msaenet.nzv(aenet.fit)
@@ -81,30 +83,33 @@ aenet = function(x, y,
   if (verbose) cat('Starting step 1 ...\n')
 
   if (init == 'enet') {
-    enet.cv = msaenet.tune.glmnet(x = x, y = y, family = family,
-                                  alphas = alphas,
-                                  tune = tune,
-                                  nfolds = nfolds, rule = rule,
-                                  ebic.gamma = ebic.gamma,
-                                  seed = seed, parallel = parallel)
+    enet.cv = msaenet.tune.glmnet(
+      x = x, y = y, family = family,
+      alphas = alphas,
+      tune = tune,
+      nfolds = nfolds, rule = rule,
+      ebic.gamma = ebic.gamma,
+      seed = seed, parallel = parallel)
   }
 
   if (init == 'ridge') {
-    enet.cv = msaenet.tune.glmnet(x = x, y = y, family = family,
-                                  alphas = 0,
-                                  tune = tune,
-                                  nfolds = nfolds, rule = rule,
-                                  ebic.gamma = ebic.gamma,
-                                  seed = seed, parallel = parallel)
+    enet.cv = msaenet.tune.glmnet(
+      x = x, y = y, family = family,
+      alphas = 0,
+      tune = tune,
+      nfolds = nfolds, rule = rule,
+      ebic.gamma = ebic.gamma,
+      seed = seed, parallel = parallel)
   }
 
   best.alpha.enet     = enet.cv$'best.alpha'
   best.lambda.enet    = enet.cv$'best.lambda'
   step.criterion.enet = enet.cv$'step.criterion'
 
-  enet.full = glmnet(x = x, y = y, family = family,
-                     alpha  = best.alpha.enet,
-                     lambda = best.lambda.enet)
+  enet.full = glmnet(
+    x = x, y = y, family = family,
+    alpha  = best.alpha.enet,
+    lambda = best.lambda.enet)
 
   bhat = as.matrix(enet.full$'beta')
   if (all(bhat == 0)) bhat = rep(.Machine$double.eps * 2, length(bhat))
@@ -113,39 +118,41 @@ aenet = function(x, y,
 
   if (verbose) cat('Starting step 2 ...\n')
 
-  aenet.cv = msaenet.tune.glmnet(x = x, y = y, family = family,
-                                 alphas = alphas,
-                                 tune = tune,
-                                 nfolds = nfolds, rule = rule,
-                                 ebic.gamma = ebic.gamma,
-                                 seed = seed + 1L, parallel = parallel,
-                                 penalty.factor = adpen)
+  aenet.cv = msaenet.tune.glmnet(
+    x = x, y = y, family = family,
+    alphas = alphas,
+    tune = tune,
+    nfolds = nfolds, rule = rule,
+    ebic.gamma = ebic.gamma,
+    seed = seed + 1L, parallel = parallel,
+    penalty.factor = adpen)
 
   best.alpha.aenet     = aenet.cv$'best.alpha'
   best.lambda.aenet    = aenet.cv$'best.lambda'
   step.criterion.aenet = aenet.cv$'step.criterion'
 
-  aenet.full = glmnet(x = x, y = y, family = family,
-                      alpha  = best.alpha.aenet,
-                      lambda = best.lambda.aenet,
-                      penalty.factor = adpen)
+  aenet.full = glmnet(
+    x = x, y = y, family = family,
+    alpha  = best.alpha.aenet,
+    lambda = best.lambda.aenet,
+    penalty.factor = adpen)
 
   # final beta stored as sparse matrix
   bhat.full = Matrix(aenet.full$'beta', sparse = TRUE)
 
-  aenet.model = list('beta'  = bhat.full,
-                     'model' = aenet.full,
-                     'beta.first'  = enet.full$'beta',
-                     'model.first' = enet.full,
-                     'best.alpha.enet'   = best.alpha.enet,
-                     'best.alpha.aenet'  = best.alpha.aenet,
-                     'best.lambda.enet'  = best.lambda.enet,
-                     'best.lambda.aenet' = best.lambda.aenet,
-                     'step.criterion'    = c(step.criterion.enet,
-                                             step.criterion.aenet),
-                     'adpen' = adpen,
-                     'seed'  = seed,
-                     'call'  = call)
+  aenet.model = list(
+    'beta'              = bhat.full,
+    'model'             = aenet.full,
+    'beta.first'        = enet.full$'beta',
+    'model.first'       = enet.full,
+    'best.alpha.enet'   = best.alpha.enet,
+    'best.alpha.aenet'  = best.alpha.aenet,
+    'best.lambda.enet'  = best.lambda.enet,
+    'best.lambda.aenet' = best.lambda.aenet,
+    'step.criterion'    = c(step.criterion.enet, step.criterion.aenet),
+    'adpen'             = adpen,
+    'seed'              = seed,
+    'call'              = call)
 
   class(aenet.model) = c('msaenet', 'msaenet.aenet')
   aenet.model
