@@ -11,7 +11,7 @@
 #' @param init Type of the penalty used in the initial
 #' estimation step. Can be \code{"mnet"} or \code{"ridge"}.
 #' @param gammas Vector of candidate \code{gamma}s (the concavity parameter)
-#' to use in MCP-Net. Default is 3.
+#' to use in MCP-Net. Default is \code{3}.
 #' @param alphas Vector of candidate \code{alpha}s to use in MCP-Net.
 #' @param tune Parameter tuning method for each estimation step.
 #' Possible options are \code{"cv"}, \code{"ebic"}, \code{"bic"},
@@ -42,12 +42,14 @@
 #' @export amnet
 #'
 #' @examples
-#' dat = msaenet.sim.gaussian(n = 150, p = 500, rho = 0.6,
-#'                            coef = rep(1, 5), snr = 2, p.train = 0.7,
-#'                            seed = 1001)
+#' dat = msaenet.sim.gaussian(
+#'   n = 150, p = 500, rho = 0.6,
+#'   coef = rep(1, 5), snr = 2, p.train = 0.7,
+#'   seed = 1001)
 #'
-#' amnet.fit = amnet(dat$x.tr, dat$y.tr,
-#'                   alphas = seq(0.2, 0.8, 0.2), seed = 1002)
+#' amnet.fit = amnet(
+#'   dat$x.tr, dat$y.tr,
+#'   alphas = seq(0.2, 0.8, 0.2), seed = 1002)
 #'
 #' print(amnet.fit)
 #' msaenet.nzv(amnet.fit)
@@ -77,83 +79,104 @@ amnet = function(x, y,
   if (verbose) cat('Starting step 1 ...\n')
 
   if (init == 'mnet') {
-    mnet.cv = msaenet.tune.ncvreg(x = x, y = y, family = family, penalty = 'MCP',
-                                  gammas = gammas, alphas = alphas,
-                                  tune = tune,
-                                  nfolds = nfolds,
-                                  ebic.gamma = ebic.gamma,
-                                  eps = eps, max.iter = max.iter,
-                                  seed = seed, parallel = parallel)
+
+    mnet.cv = msaenet.tune.ncvreg(
+      x = x, y = y, family = family, penalty = 'MCP',
+      gammas = gammas, alphas = alphas,
+      tune = tune,
+      nfolds = nfolds,
+      ebic.gamma = ebic.gamma,
+      eps = eps, max.iter = max.iter,
+      seed = seed, parallel = parallel)
+
+    best.gamma.mnet     = mnet.cv$'best.gamma'
+    best.alpha.mnet     = mnet.cv$'best.alpha'
+    best.lambda.mnet    = mnet.cv$'best.lambda'
+    step.criterion.mnet = mnet.cv$'step.criterion'
+
+    mnet.full = .ncvnet(
+      x = x, y = y, family = family, penalty = 'MCP',
+      gamma  = best.gamma.mnet,
+      alpha  = best.alpha.mnet,
+      lambda = best.lambda.mnet,
+      eps = eps, max.iter = max.iter)
+
+    bhat = .coef.ncvreg(mnet.full, nvar)
+
   }
 
   if (init == 'ridge') {
-    mnet.cv = msaenet.tune.ncvreg(x = x, y = y, family = family, penalty = 'MCP',
-                                  gammas = gammas, alphas = 1e-16,
-                                  tune = tune,
-                                  nfolds = nfolds,
-                                  ebic.gamma = ebic.gamma,
-                                  eps = eps, max.iter = max.iter,
-                                  seed = seed, parallel = parallel)
+
+    mnet.cv = msaenet.tune.glmnet(
+      x = x, y = y, family = family,
+      alphas = 0,
+      tune = tune,
+      nfolds = nfolds, rule = 'lambda.min',
+      ebic.gamma = ebic.gamma,
+      seed = seed, parallel = parallel)
+
+    best.gamma.mnet     = NA
+    best.alpha.mnet     = mnet.cv$'best.alpha'
+    best.lambda.mnet    = mnet.cv$'best.lambda'
+    step.criterion.mnet = mnet.cv$'step.criterion'
+
+    mnet.full = glmnet(
+      x = x, y = y, family = family,
+      alpha  = best.alpha.mnet,
+      lambda = best.lambda.mnet)
+
+    bhat = as.matrix(mnet.full$'beta')
+
   }
 
-  best.gamma.mnet     = mnet.cv$'best.gamma'
-  best.alpha.mnet     = mnet.cv$'best.alpha'
-  best.lambda.mnet    = mnet.cv$'best.lambda'
-  step.criterion.mnet = mnet.cv$'step.criterion'
-
-  mnet.full = .ncvnet(x = x, y = y, family = family, penalty = 'MCP',
-                      gamma  = best.gamma.mnet,
-                      alpha  = best.alpha.mnet,
-                      lambda = best.lambda.mnet,
-                      eps = eps, max.iter = max.iter)
-
-  bhat = .coef.ncvreg(mnet.full, nvar)
   if (all(bhat == 0)) bhat = rep(.Machine$double.eps * 2, length(bhat))
 
   adpen = (pmax(abs(bhat), .Machine$double.eps))^(-scale)
 
   if (verbose) cat('Starting step 2 ...\n')
 
-  amnet.cv = msaenet.tune.ncvreg(x = x, y = y, family = family, penalty = 'MCP',
-                                 gammas = gammas, alphas = alphas,
-                                 tune = tune,
-                                 nfolds = nfolds,
-                                 ebic.gamma = ebic.gamma,
-                                 eps = eps, max.iter = max.iter,
-                                 seed = seed + 1L, parallel = parallel,
-                                 penalty.factor = adpen)
+  amnet.cv = msaenet.tune.ncvreg(
+    x = x, y = y, family = family, penalty = 'MCP',
+    gammas = gammas, alphas = alphas,
+    tune = tune,
+    nfolds = nfolds,
+    ebic.gamma = ebic.gamma,
+    eps = eps, max.iter = max.iter,
+    seed = seed + 1L, parallel = parallel,
+    penalty.factor = adpen)
 
   best.gamma.amnet     = amnet.cv$'best.gamma'
   best.alpha.amnet     = amnet.cv$'best.alpha'
   best.lambda.amnet    = amnet.cv$'best.lambda'
   step.criterion.amnet = amnet.cv$'step.criterion'
 
-  amnet.full = .ncvnet(x = x, y = y, family = family, penalty = 'MCP',
-                       gamma  = best.gamma.amnet,
-                       alpha  = best.alpha.amnet,
-                       lambda = best.lambda.amnet,
-                       eps = eps, max.iter = max.iter,
-                       penalty.factor = adpen)
+  amnet.full = .ncvnet(
+    x = x, y = y, family = family, penalty = 'MCP',
+    gamma  = best.gamma.amnet,
+    alpha  = best.alpha.amnet,
+    lambda = best.lambda.amnet,
+    eps = eps, max.iter = max.iter,
+    penalty.factor = adpen)
 
   # final beta stored as sparse matrix
   bhat.full  = Matrix(.coef.ncvreg(amnet.full, nvar), sparse = TRUE)
   bhat.first = Matrix(.coef.ncvreg(mnet.full,  nvar), sparse = TRUE)
 
-  amnet.model = list('beta'  = bhat.full,
-                     'model' = amnet.full,
-                     'beta.first'  = bhat.first,
-                     'model.first' = mnet.full,
-                     'best.alpha.mnet'      = best.alpha.mnet,
-                     'best.alpha.amnet'     = best.alpha.amnet,
-                     'best.lambda.mnet'     = best.lambda.mnet,
-                     'best.lambda.amnet'    = best.lambda.amnet,
-                     'best.gamma.mnet'      = best.gamma.mnet,
-                     'best.gamma.amnet'     = best.gamma.amnet,
-                     'step.criterion'       = c(step.criterion.mnet,
-                                                step.criterion.amnet),
-                     'adpen' = adpen,
-                     'seed'  = seed,
-                     'call'  = call)
+  amnet.model = list(
+    'beta'              = bhat.full,
+    'model'             = amnet.full,
+    'beta.first'        = bhat.first,
+    'model.first'       = mnet.full,
+    'best.alpha.mnet'   = best.alpha.mnet,
+    'best.alpha.amnet'  = best.alpha.amnet,
+    'best.lambda.mnet'  = best.lambda.mnet,
+    'best.lambda.amnet' = best.lambda.amnet,
+    'best.gamma.mnet'   = best.gamma.mnet,
+    'best.gamma.amnet'  = best.gamma.amnet,
+    'step.criterion'    = c(step.criterion.mnet, step.criterion.amnet),
+    'adpen'             = adpen,
+    'seed'              = seed,
+    'call'              = call)
 
   class(amnet.model) = c('msaenet', 'msaenet.amnet')
   amnet.model
