@@ -20,6 +20,14 @@
 #' variables will be used as labels.
 #' @param label.vars Labels to use for all the variables
 #' if \code{label = "TRUE"}.
+#' @param label.pos Position of the labels. See argument
+#' \code{pos} in \code{\link[graphics]{text}} for details.
+#' @param label.offset Offset of the labels. See argument
+#' \code{offset} in \code{\link[graphics]{text}} for details.
+#' @param label.cex Character expansion factor of the labels.
+#' See argument \code{cex} in \code{\link[graphics]{text}} for details.
+#' @param xlab Title for x axis. If is \code{NULL}, will use the default title.
+#' @param ylab Title for y axis. If is \code{NULL}, will use the default title.
 #' @param ... Other parameters (not used).
 #'
 #' @method plot msaenet
@@ -50,7 +58,9 @@
 
 plot.msaenet = function(x, type = c('coef', 'criterion'), nsteps = NULL,
                         highlight = TRUE, col = NULL,
-                        label = FALSE, label.vars = NULL, ...) {
+                        label = FALSE, label.vars = NULL,
+                        label.pos = 2, label.offset = 0.3, label.cex = 0.7,
+                        xlab = NULL, ylab = NULL, ...) {
 
   type = match.arg(type)
 
@@ -73,14 +83,19 @@ plot.msaenet = function(x, type = c('coef', 'criterion'), nsteps = NULL,
   if (type == 'coef') {
     nzv.idx = msaenet.nzv(x)
     .parcor(beta.mat, nsteps, best.step, nzv.idx,
-            highlight, col, label, label.vars)
+            highlight, col,
+            label, label.vars,
+            label.pos, label.offset, label.cex,
+            xlab, ylab)
   }
 
   if (type == 'criterion') {
     if (is.null(x$'post.criterion'))
       stop('No post selection ICs available, since `tune.nsteps = "max"
            or it is a one-step-only adaptive model object`') else
-             .scree(x$'post.criterion', nsteps, best.step, highlight)
+             .scree(x$'post.criterion',
+                    nsteps, best.step, highlight,
+                    xlab, ylab)
   }
 
   invisible()
@@ -89,28 +104,35 @@ plot.msaenet = function(x, type = c('coef', 'criterion'), nsteps = NULL,
 
 # parallel coordinates plot
 .parcor = function(x, nsteps, best.step, nzv.idx,
-                   highlight, col, label, label.vars) {
+                   highlight, col,
+                   label, label.vars,
+                   label.pos, label.offset, label.cex,
+                   xlab, ylab) {
 
   x = x[, 1L:nsteps]
   xmin = min(x)
   xmax = max(x)
 
+  if (is.null(xlab)) xlab = 'Number of Estimation Steps'
+  if (is.null(ylab)) ylab = 'Coefficients'
+
   # box
-  matplot(1L:nsteps, t(x), xlab = '', ylab = 'Coefficients',
+  matplot(1L:nsteps, t(x), xlab = xlab, ylab = ylab,
           xaxt = 'n', yaxt = 'n', type = 'n', axes = TRUE)
 
   # axes with only ticks
   axis(2, at = c(xmin, 0, xmax), labels = c('Min', '0', 'Max'), lwd = 0, lwd.ticks = 1)
-  axis(1, at = 1L:nsteps, labels = paste('Step', 1L:nsteps), lwd = 0, lwd.ticks = 1)
+  axis(1, at = 1L:nsteps, labels = as.character(1L:nsteps), lwd = 0, lwd.ticks = 1)
 
   # step lines
-  for (i in 1L:nsteps) lines(x = c(i, i), y = c(xmin, xmax), col = 'grey90')
+  for (i in 1L:nsteps)
+    lines(x = c(i, i), y = c(xmin - 42, xmax + 42), lty = 3, col = 'grey70')
 
   # highlight optimal step
   if (highlight) {
-    lines(x = c(best.step, best.step), y = c(xmin, xmax),
+    lines(x = c(best.step, best.step), y = c(xmin - 42, xmax + 42),
           col = 'white', lty = 1, lwd = 1.5)
-    lines(x = c(best.step, best.step), y = c(xmin, xmax),
+    lines(x = c(best.step, best.step), y = c(xmin - 42, xmax + 42),
           col = 'darkred', lty = 2, lwd = 1.5)
   }
 
@@ -121,13 +143,13 @@ plot.msaenet = function(x, type = c('coef', 'criterion'), nsteps = NULL,
   matlines(1L:nsteps, t(x), lty = 1, lwd = 1.2, col = col)
 
   # zero line
-  lines(x = c(1L, nsteps), y = c(0, 0))
+  lines(x = c(0L, nsteps + 1L), y = c(0, 0), lwd = 1.2)
 
   # label variables
   if (label & is.null(label.vars))
     text(x = best.step, y = x[nzv.idx, best.step],
          labels = as.character(nzv.idx),
-         offset = 0.3, pos = 2, cex = 0.7)
+         pos = label.pos, offset = label.offset, cex = label.cex)
 
   if (label & !is.null(label.vars)) {
 
@@ -135,7 +157,7 @@ plot.msaenet = function(x, type = c('coef', 'criterion'), nsteps = NULL,
       stop('Length of `label.vars` should be the same as the number of variables') else
         text(x = best.step, y = x[nzv.idx, best.step],
              labels = label.vars[nzv.idx],
-             offset = 0.3, pos = 2, cex = 0.7)
+             pos = label.pos, offset = label.offset, cex = label.cex)
 
   }
 
@@ -143,18 +165,21 @@ plot.msaenet = function(x, type = c('coef', 'criterion'), nsteps = NULL,
 
 }
 
-.scree = function(x, nsteps, best.step, highlight) {
+.scree = function(x, nsteps, best.step, highlight, xlab, ylab) {
 
   x = x[1L:nsteps]
 
-  plot(1L:length(x), x, type = 'b', xaxt = 'n',
-       xlab = '', ylab = 'Post Selection Criterion')
+  if (is.null(xlab)) xlab = 'Number of Estimation Steps'
+  if (is.null(ylab)) ylab = 'Model Selection Criterion'
 
-  axis(1, at = 1L:nsteps, labels = paste('Step', 1L:nsteps),
+  plot(1L:length(x), x, type = 'b', xaxt = 'n', xlab = xlab, ylab = ylab)
+
+  axis(1, at = 1L:nsteps, labels = as.character(1L:nsteps),
        lwd = 0, lwd.ticks = 1)
 
-  if (highlight) lines(x = c(best.step, best.step),
-                       y = c(min(x) - 0.5, max(x) + 0.5),
-                       col = 'darkred', lty = 2, lwd = 1.5)
+  if (highlight) lines(
+    x = c(best.step, best.step),
+    y = c(min(x) - 0.5, max(x) + 0.5),
+    col = 'darkred', lty = 2, lwd = 1.5)
 
 }
